@@ -1,5 +1,5 @@
 """
-SQLObject 0.12.3
+SQLObject 0.13.0
 ----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -44,8 +44,8 @@ from formencode import schema, compound
 from util.threadinglocal import local
 
 import sys
-if sys.version_info[:3] < (2, 2, 0):
-    raise ImportError, "SQLObject requires Python 2.2.0 or later"
+if sys.version_info[:3] < (2, 4, 0):
+    raise ImportError, "SQLObject requires Python 2.4.0 or later"
 
 """
 This thread-local storage is needed for RowCreatedSignals. It gathers
@@ -853,7 +853,8 @@ class SQLObject(object):
                     del values[key]
             cls.sqlmeta = type('sqlmeta', (superclass,), values)
 
-        cls.sqlmeta.setClass(cls)
+        if not is_base: # Do not pollute the base sqlmeta class
+            cls.sqlmeta.setClass(cls)
 
     _SO_setupSqlmeta = classmethod(_SO_setupSqlmeta)
 
@@ -1317,7 +1318,7 @@ class SQLObject(object):
         for n, v in zip(name, value):
             from_python = getattr(cls, '_SO_from_python_' + n)
             if from_python:
-                v = from_python(v, cls)
+                v = from_python(v, sqlbuilder.SQLObjectState(cls))
             new_value.append(v)
         condition = sqlbuilder.AND(*[getattr(cls.q, n)==v for n,v in zip(name, new_value)])
         return (connection or cls._connection)._SO_selectOneAlt(
@@ -1676,6 +1677,22 @@ class SQLObject(object):
        return NotImplemented
 
 
+    def __getstate__(self):
+        if self.sqlmeta._perConnection:
+            from pickle import PicklingError
+            raise PicklingError('Cannot pickle an SQLObject instance that has a per-instance connection')
+        d = self.__dict__.copy()
+        del d['sqlmeta']
+        del d['_SO_writeLock']
+        return d
+
+    def __setstate__(self, d):
+        self.__init__(_SO_fetch_no_create=1)
+        self._SO_writeLock = threading.Lock()
+        self.__dict__.update(d)
+        self.__class__._connection.cache.put(self.id, self.__class__, self)
+
+
 def capitalize(name):
     return name[0].capitalize() + name[1:]
 
